System.register([], (function (exports) {
	'use strict';
	return {
		execute: (function () {

			var value = exports('v', 42);
			const x = exports('x', 3);

		})
	};
}));
